diff Modules/parsermodule.c @ 38314:1fdf29a88f0e legacy-trunk

Replace PyObject_CallFunction calls with only object args with PyObject_CallFunctionObjArgs, which is 30% faster.
author Georg Brandl <georg@python.org>
date Thu, 25 May 2006 19:15:31 +0000
parents 8a188036b713
children 45ac5196fa67 f8a90d1825ce
line wrap: on
line diff
--- a/Modules/parsermodule.c	Thu May 25 19:15:27 2006 +0000
+++ b/Modules/parsermodule.c	Thu May 25 19:15:31 2006 +0000
@@ -3267,8 +3267,8 @@
             && (pickler != NULL)) {
             PyObject *res;
 
-            res = PyObject_CallFunction(func, "OOO", &PyST_Type, pickler,
-                                        pickle_constructor);
+            res = PyObject_CallFunctionObjArgs(func, &PyST_Type, pickler,
+                                               pickle_constructor, NULL);
             Py_XDECREF(res);
         }
         Py_XDECREF(func);